/***************************************************************************
                          ktabwidget.h  -  description
                             -------------------
    begin                : Sam Feb 1 2003
    copyright            : (C) 2003 by Matthias Reif
    email                : matthias.reif@informatik.tu-chemnitz.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KSINGLETABWIDGET_H
#define KSINGLETABWIDGET_H

#include <qwidget.h>
#include <qlayout.h>

/**
  *@author Matthias Reif
  */
class KSingleTabWidget : public QWidget
{
   Q_OBJECT
public:
	KSingleTabWidget( QWidget *parent=0, const char *name=0 );
	~KSingleTabWidget();
	QGridLayout* getLayout();
protected:
	QGridLayout* layout;
};

#endif
